==> pur-api-1.2.3.33-yybpc-20250723.153014-1-sources.jar: com/elitesland/pur/dto/rns/PurRnsRpcDTO.java <==
package com.elitesland.pur.dto.rns;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "退货申请单")
public class PurRnsRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("ID")
    private Long id;

    @ApiModelProperty("单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("发货仓库")
    private Long fromWhId;

    @ApiModelProperty("收货供应商")
    private Long suppId;

    @ApiModelProperty("收货供应商")
    private String suppCode;

    @ApiModelProperty("收货供应商")
    private String suppName;

    @ApiModelProperty("状态")
    private String docStatus;

    @ApiModelProperty("关联单据2编码")
    private String relateDoc2No;

    @ApiModelProperty("关联单据2ID")
    private Long relateDoc2Id;

    private List<PurRnsDRpcDTO> rnsDRpcDTOS;
}

==> pur-api-1.2.3.48-yybpc-20250807.075420-1-sources.jar: com/elitesland/pur/dto/rns/PurRnsRpcDTO.java <==
package com.elitesland.pur.dto.rns;

import com.elitescloud.cloudt.common.annotation.Comment;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.persistence.Column;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;

@Data
@ApiModel(description = "退货申请单")
public class PurRnsRpcDTO implements Serializable {

    private static final long serialVersionUID = -9066194839868175002L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty("ID")
    private Long id;

    @ApiModelProperty("单号")
    private String docNo;

    @ApiModelProperty("创建日期")
    private LocalDateTime createTime;

    @ApiModelProperty("备注")
    private String remark;

    @ApiModelProperty("地址号")
    Long addrNo;

    @ApiModelProperty("承运商")
    private String carrier;

    @ApiModelProperty("配送方式")
    private String deliverMethod;

    @ApiModelProperty("物流单号")
    private String logisDocNo;

    @ApiModelProperty("发货仓库")
    private Long fromWhId;

    @ApiModelProperty("收货供应商")
    private Long suppId;

    @ApiModelProperty("收货供应商")
    private String suppCode;

    @ApiModelProperty("收货供应商")
    private String suppName;

    @ApiModelProperty("状态")
    private String docStatus;

    @ApiModelProperty("关联单据2编码")
    private String relateDoc2No;

    @ApiModelProperty("关联单据2ID")
    private Long relateDoc2Id;

    private Long relateDocId;

    @ApiModelProperty("关联单据编码")
    private String relateDocNo;

    @ApiModelProperty("关联单据ID")
    private String rootDocCls;

    private Long rootDocId;

    private String rootDocNo;


    private List<PurRnsDRpcDTO> rnsDRpcDTOS;
}
